Module ids

Module ids 

Strongly-typed identifiers used across task/run/attempt domain entities. ID newtypes used by core domain entities.

Re-exports

pub use actor_id::ActorId;
pub use attempt_id::AttemptId;
pub use department_id::DepartmentId;
pub use department_id::DepartmentIdError;
pub use ledger_entry_id::LedgerEntryId;
pub use run_id::RunId;
pub use task_id::TaskId;
pub use tenant_id::TenantId;

Modules

actor_id
Actor identifier type. Unique identifier for a remote actor registered with the hub.
attempt_id
Attempt identifier type. Per-attempt identifier for execution lineage tracking.
department_id
Department identifier type.
ledger_entry_id
Ledger entry identifier type. Unique identifier for an append-only ledger entry.
run_id
Run identifier type. Stable run identity and idempotency key for external side effects.
task_id
Task identifier type. Unique identifier for a durable task specification.
tenant_id
Tenant identifier type. Unique identifier for an organizational tenant.